Lattices
--------

.. autoclass:: brille._brille.Bravais

.. autoclass:: brille._brille.Lattice
  :members:

.. autoclass:: brille._brille.Direct
  :members:
  :show-inheritance:

.. autoclass:: brille._brille.Reciprocal
  :members:
  :show-inheritance:
